==> fwobac-2.1.tar.gz: fwobac-2.1/html_utils.h <==
/* $Id: html_utils.h,v 1.10 2018/12/12 00:14:11 rlr Exp $ */

/*
 * Copyright (c) 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _HTML_UTILS_H_
#define _HTML_UTILS_H_


#include <sys/types.h>

#include <stdbool.h>
#include <stddef.h>


/*
 * void
 * text_to_html(const char *t, bool nlx, char *h, size_t *sz);
 *
 * Converts from text to simple HTML (or just reports the buffer size required
 * for such a conversion).
 *
 * t must be NULL or a NUL-terminated string.  h must be NULL or a buffer of
 * sufficient size to hold the converted string.  sz must be non-NULL.
 *
 * If t is NULL, *sz is set to zero and, if non-NULL, h is set to the empty
 * string.
 * If t is non-NULL, the type of conversion is determined by nlx:
 * - if nlx is false, only character reference replacement (for '"', '&', '<',
 *   and '>') is undertaken;
 * - if nlx is true, '\r' characters in t are ignored (and elided from
 *   output), leading and trailing '\n' characters are elided, sequences of two
 *   or more '\n' characters delimit paragraphs (<p>/</p>), and single '\n'
 *   characters are converted to linebreaks; if t is the empty string, an
 *   empty paragraph is generated.
 * sz is set to the buffer size required for the converted string.  In if h
 * is non-NULL, the HTML equivalent of t is copied to it.
 */
void	 text_to_html(const char *, bool, char *, size_t *);


/*
 * char *
 * alloc_text_to_html(const char *t, bool nlx);
 *
 * Returns a newly allocated buffer containing the text_to_html() conversion
 * of t (according to nlx), or NULL if t is NULL or allocation failure occurs.
 */
char	*alloc_text_to_html(const char *, bool);


/*
 * void
 * html_named_char_ref_utf8_info(const char *h, const char **u, size_t *hsz,
 *     size_t *usz);
 *
 * If the prefix of h is an HTML named character reference, the UTF-8 value of
 * the reference is assigned to *u, and the lengths (in octets) of the
 * name (including '&' and ';') and UTF-8 value are assigned to *hsz and *usz
 * (respectively) if those pointers are non-NULL.  If the prefix of h is not a
 * named character reference, *u is set to NULL, and the lengths are reported
 * as zero.  h and u must be non-NULL.
 */
void	 html_named_char_ref_utf8_info(const char *, const char **, size_t *,
    size_t *);


/*
 * const char *
 * html_named_char_ref_to_utf8(const char *h);
 *
 * Wrapper funcction for html_named_char_ref_utf8_info() which returns the
 * UTF-8 value (or NULL).
 */
const char	*html_named_char_ref_to_utf8(const char *);


/*
 * void
 * html_num_char_ref_utf8_info(const char *h, uint32_t *cp, size_t *hsz);
 *
 * Evaluates the prefix of h (which must be non-NULL) as an HTML numeric
 * character reference.  If the prefix is not a well-formed reference, *cp
 * is set to UTF8_INVALID_CP and *hsz is set to zero; if the the prefix is
 * well-formed but invalid (e.g. number out-of-range), *cp is set to
 * UTF8_INVALID_CP and *hsz is assigned the prefix length (from '&' to ';',
 * inclusive); if the prefix is a valid reference, *cp is set to the code point
 * and *hsz is assigned the prefix length.  Note that a code point of U+0000
 * is considered valid in this context.
 */
void	 html_num_char_ref_utf8_info(const char *, uint32_t *, size_t *);


/*
 * void
 * html_to_text(const char *h, bool r, char *t, size_t sz)
 *
 * Copies to t, which must be of size no less than sz, a version of h with
 * HTML markup ('<'...'>') stripped, and, iff r is false, character references
 * replaced by UTF-8 character encoded versions.  Invalid UTF-8 sequences and
 * (iff r is false) character references are replaced by the encoding of UTF-8
 * code point U+0x0FFFD.  If t is of insufficient size to hold the entire
 * output, the string is truncated.
 */
void	 html_to_text(const char *, bool, char *, size_t)
	__attribute__ ((__bounded__ (__string__, 3, 4 )));


#endif /* !_HTML_UTILS_H_ */

==> fwobac-2.3.tar.gz: fwobac-2.3/html_utils.h <==
/* $Id: html_utils.h,v 1.11 2023/11/19 05:28:06 rlr Exp $ */

/*
 * Copyright (c) 2018, 2023 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _HTML_UTILS_H_
#define _HTML_UTILS_H_


#include <sys/types.h>

#include <stdbool.h>
#include <stddef.h>


/*
 * void
 * text_to_html(const char *t, bool nlx, char *h, size_t *sz);
 *
 * Converts from text to simple HTML (or just reports the buffer size required
 * for such a conversion).
 *
 * t must be NULL or a NUL-terminated string.  h must be NULL or a buffer of
 * sufficient size to hold the converted string.  sz must be non-NULL.
 *
 * If t is NULL, *sz is set to zero and, if non-NULL, h is set to the empty
 * string.
 * If t is non-NULL, the type of conversion is determined by nlx:
 * - if nlx is false, only character reference replacement (for '"', '&', '<',
 *   and '>') is undertaken;
 * - if nlx is true, '\r' characters in t are ignored (and elided from
 *   output), leading and trailing '\n' characters are elided, sequences of two
 *   or more '\n' characters delimit paragraphs (<p>/</p>), and single '\n'
 *   characters are converted to linebreaks; if t is the empty string, an
 *   empty paragraph is generated.
 * sz is set to the buffer size required for the converted string.  In if h
 * is non-NULL, the HTML equivalent of t is copied to it.
 */
void	 text_to_html(const char *, bool, char *, size_t *);


/*
 * char *
 * alloc_text_to_html(const char *t, bool nlx);
 *
 * Returns a newly allocated buffer containing the text_to_html() conversion
 * of t (according to nlx), or NULL if t is NULL or allocation failure occurs.
 */
char	*alloc_text_to_html(const char *, bool);


/*
 * void
 * html_named_char_ref_utf8_info(const char *h, const char **u, size_t *hsz,
 *     size_t *usz);
 *
 * If the prefix of h is an HTML named character reference, the UTF-8 value of
 * the reference is assigned to *u, and the lengths (in octets) of the
 * name (including '&' and ';') and UTF-8 value are assigned to *hsz and *usz
 * (respectively) if those pointers are non-NULL.  If the prefix of h is not a
 * named character reference, *u is set to NULL, and the lengths are reported
 * as zero.  h and u must be non-NULL.
 */
void	 html_named_char_ref_utf8_info(const char *, const char **, size_t *,
    size_t *);


/*
 * const char *
 * html_named_char_ref_to_utf8(const char *h);
 *
 * Wrapper function for html_named_char_ref_utf8_info() which returns the
 * UTF-8 value (or NULL).
 */
const char	*html_named_char_ref_to_utf8(const char *);


/*
 * void
 * html_num_char_ref_utf8_info(const char *h, uint32_t *cp, size_t *hsz);
 *
 * Evaluates the prefix of h (which must be non-NULL) as an HTML numeric
 * character reference.  If the prefix is not a well-formed reference, *cp
 * is set to UTF8_INVALID_CP and *hsz is set to zero; if the the prefix is
 * well-formed but invalid (e.g. number out-of-range), *cp is set to
 * UTF8_INVALID_CP and *hsz is assigned the prefix length (from '&' to ';',
 * inclusive); if the prefix is a valid reference, *cp is set to the code point
 * and *hsz is assigned the prefix length.  Note that a code point of U+0000
 * is considered valid in this context.
 */
void	 html_num_char_ref_utf8_info(const char *, uint32_t *, size_t *);


/*
 * void
 * html_to_text(const char *h, bool r, char *t, size_t sz)
 *
 * Copies to t, which must be of size no less than sz, a version of h with
 * HTML markup ('<'...'>') stripped, and, iff r is false, character references
 * replaced by UTF-8 character encoded versions.  Invalid UTF-8 sequences and
 * (iff r is false) character references are replaced by the encoding of UTF-8
 * code point U+0x0FFFD.  If t is of insufficient size to hold the entire
 * output, the string is truncated.
 */
void	 html_to_text(const char *, bool, char *, size_t)
	__attribute__ ((__bounded__ (__string__, 3, 4 )));


#endif /* !_HTML_UTILS_H_ */
